require "spec_helper"

describe AfTalk::Client do
  subject do
    class ExampleKlass
      extend AfTalk::Client
    end
    ExampleKlass
  end

  before(:all) { reset_config }
  let(:response) { double(headers: { "content-type" => "application/json" }) }

  describe "#send_message" do
    let(:options) {
      { to: "+14125554563", message: "Hello World!", foo: "bar" }
    }

    context "with all required options" do
      it "it instantiates a send message response" do
        allow(AfTalk::Request).to receive(:post).
          with("/messaging", options).
          and_return(response)
        allow(AfTalk::SendMessageResponse).to receive(:new).with(response)

        subject.send_message(options)

        expect(AfTalk::SendMessageResponse).to have_received(:new).with(response)
      end
    end

    context "without some required options" do
      let(:options) { {} }

      it "raises a missing options error" do
        expect { subject.send_message(options) }.to raise_error(ArgumentError)
      end
    end
  end

  describe "#fetch_messages" do
    let(:options) { { last_received_id: "abc123" } }

    context "with all required options" do
      it "it instantiates a fetch messages response" do
        allow(AfTalk::Request).to receive(:get).
          with("/messaging", lastReceivedId: options[:last_received_id]).
          and_return(response)
        allow(AfTalk::FetchMessagesResponse).to receive(:new).with(response)

        subject.fetch_messages(options)

        expect(AfTalk::FetchMessagesResponse).to have_received(:new).with(response)
      end
    end
  end
end
