require "spec_helper"

describe AfTalk::Configuration do
  let(:api_key) { "abc123" }
  let(:sandbox) { true }
  let(:user_name) { "Thrive Global" }

  before(:each) do
    allow(AfTalk::Connection).to receive(:clear)

    described_class.configure do |config|
      config.api_key = api_key
      config.sandbox = sandbox
      config.user_name = user_name
    end
  end

  describe ".api_key" do
    let(:api_key) { nil }

    before(:each) { stub_env_vars("AFRICAS_TALKING_API_KEY" => "env_key") }

    context "when no api key is configured" do
      it "uses the value set in dotenv" do
        expect(described_class.api_key).to eq("env_key")
      end
    end
  end

  describe ".configure" do
    it "allows setting version, sandbox, and api_key values" do
      expect(described_class.api_key).to eq("abc123")
      expect(described_class.user_name).to eq("Thrive Global")
      expect(described_class.sandbox).to be
    end

    it "clears the connection" do
      expect(AfTalk::Connection).to have_received(:clear)
    end
  end

  describe ".sandbox" do
    let(:sandbox) { nil }

    before(:each) { stub_env_vars("AFRICAS_TALKING_SANDBOX" => "env_sandbox") }

    context "when no sandbox value is configured" do
      it "uses the value set in dotenv" do
        expect(described_class.sandbox).to eq("env_sandbox")
      end
    end
  end

  describe ".user_name" do
    let(:user_name) { nil }

    before(:each) { stub_env_vars("AFRICAS_TALKING_USER_NAME" => "env_user_name") }

    context "when no api key is configured" do
      it "uses the value set in dotenv" do
        expect(described_class.user_name).to eq("env_user_name")
      end
    end
  end

  describe ".version" do
    context "returns the default version" do
      it "returns the default version" do
        expect(described_class.version).to eq("version1")
      end
    end
  end
end
