require "spec_helper"

describe AfTalk::Connection do
  describe ".build" do
    let(:instance) { double }

    before(:each) do
      allow(described_class).to receive(:new).and_return(instance)
      allow(instance).to receive(:build)
    end

    it "calls #build on an instance" do
      described_class.build
      expect(instance).to have_received(:build)
    end

    it "is memoized" do
      first_connection = described_class.build
      second_connection = described_class.build
      expect(first_connection).to be(second_connection)
    end
  end

  describe ".clear" do
    it "clears the memoization of the connection" do
      first_connection = described_class.build
      described_class.clear
      second_connection = described_class.build
      expect(first_connection).not_to be(second_connection)
    end
  end

  describe "#build" do
    let(:connection) { described_class.new.build }
    let(:base_url) { connection.url_prefix.to_s }

    context "in all modes" do
      it "has the expected properties" do
        headers = connection.headers

        expect(connection.scheme).to eq("https")
        expect(headers["Accept"]).to eq("application/json")
        expect(headers["Apikey"]).to eq(AfTalk::Configuration.api_key)
      end
    end

    context "in sandbox mode" do
      before(:each) do
        stub_env_vars("SANDBOX" => "true")
      end

      it "uses the sandbox url" do
        expect(base_url).to match(described_class::SANDBOX_URL)
      end
    end

    context "in production mode" do
      before(:each) do
        stub_env_vars("AFRICAS_TALKING_SANDBOX" => nil)
      end

      it "uses the production url" do
        expect(base_url).to match(described_class::URL)
      end
    end
  end
end
