require "spec_helper"

describe AfTalk::Request do
  let(:connection) { double("connection") }
  let(:get_response) { double("get_response") }
  let(:post_response) { double("post_response") }
  let(:user_name) { "Thrive Global" }
  let(:default_params) { { username: user_name } }
  let(:options) { { foo: "bar" } }

  before(:each) do
    allow(AfTalk::Connection).to receive(:build).and_return(connection)
    allow(AfTalk::Configuration).to receive(:user_name).and_return(user_name)
  end

  describe ".get" do
    it "creates an instance and sends #get to it" do
      instance = double
      allow(described_class).to receive(:new).and_return(instance)
      allow(instance).to receive(:get).
        with("/path", options).
        and_return(get_response)

      expect(described_class.get("/path", options)).to eq(get_response)
    end
  end

  describe ".post" do
    it "creates an instance and sends #post to it" do
      instance = double
      allow(described_class).to receive(:new).and_return(instance)
      allow(instance).to receive(:post).
        with("/path", options).
        and_return(get_response)

      expect(described_class.post("/path", options)).to eq(get_response)
    end
  end

  describe "#get" do
    it "returns the response of doing a get to an API endpoint" do
      allow(connection).to receive(:get).
        with("/version1/test", options.merge(default_params)).
        and_return(get_response)

      expect(described_class.new.get("/test", options)).to eq(get_response)
    end
  end

  describe "#post" do
    it "returns the response of doing a post to an API endpoint" do
      allow(connection).to receive(:post).
        with("/version1/test", options.merge(default_params)).
        and_return(post_response)

      expect(described_class.new.post("/test", options)).to eq(post_response)
    end
  end
end
