require "spec_helper"

describe AfTalk::SendMessageResponse do
  describe ".new" do
    subject { described_class.new(response) }

    context "when the response is a success" do
      let(:response) { double(body: data, status: 201) }
      let(:data) do
        {
          SMSMessageData: {
            Message: "The message was delivered.",
            Recipients: [recipient_data],
          },
        }
      end
      let(:recipient_data) { double("RecipientData") }
      let(:message_status) { double("MessageStatus") }

      before(:each) do
        allow(AfTalk::SmsMessageStatus).to receive(:new).
          with(recipient_data).
          and_return(message_status)
      end

      it "sets a message and initializes recipients" do
        expect(subject).to be_kind_of(AfTalk::Response)
        expect(subject.message).to eq(response.body[:SMSMessageData][:Message])
        expect(subject.recipients).to eq([message_status])
      end
    end

    context "when the response is not a success" do
      let(:response) { double(body: "This failed.", status: 400) }

      it "doesn't set a message or recipients" do
        expect(subject).to be_kind_of(AfTalk::Response)
        expect(subject.message).to be_nil
        expect(subject.recipients).to be_nil
      end
    end
  end
end
